{% for error in form.non_field_errors %}
    {% include 'ecom_statics/includes/error_alert.html' with message=error|safe %}
{% endfor %}

{% for field in form %}
    {% for error in field.errors %}
        {% include 'ecom_statics/includes/error_alert.html' with label=field.label message=error|safe %}
    {% endfor %}
{% endfor %}
