<footer class="app-footer">
    {% block ecom_statics_footer_right_content %}
        <div class="float-end d-none d-sm-inline">v{{ WEB_VERSION|default:'0.0.0' }}</div>
    {% endblock %}

    {% block ecom_statics_footer_left_content %}
        <strong>
            <span>Copyright</span>
            <i class="bi bi-c-circle align-middle"></i>
            <span id="current-year"></span>
            <a href="https://ecom.com.ar" class="text-decoration-none">ECOM Chaco S.A.</a>
        </strong>

        <span>Todos los derechos reservados.</span>

        <script>
            document.getElementById('current-year').textContent = new Date().getFullYear();
        </script>
    {% endblock %}
</footer>
