/* ************************************************ SELECT2 ************************************************ */

.select2-container .select2-selection--single,
.select2-container .select2-selection--multiple {
    min-height: 42px;
    padding: 8px 12px;
    border-radius: 8px;
    border: 1px solid var(--bs-border-color);
    font-size: 16px;
}

.select2-results__option {
    font-size: 16px;
}

.select2-results__option--highlighted[aria-selected] {
    background-color: var(--bs-primary) !important;
}

.select2-container--focus .select2-selection--single,
.select2-container--focus .select2-selection--multiple {
    border: 1px solid var(--bs-primary) !important;
}

/* ************************************************ SELECT2 SINGLE ************************************************ */

.select2-container .select2-selection--single .select2-selection__rendered {
    padding-left: 0px;
    padding-right: 5px;
    line-height: inherit;
    color: inherit;
}

.select2-container--default .select2-selection--single .select2-selection__arrow {
    top: 50%;
    transform: translateY(-50%);
}

/* ************************************************ SELECT2 MULTIPLE ************************************************ */

.select2-container .select2-selection--multiple .select2-selection__rendered {
    display: flex;
    flex-wrap: wrap;
    gap: 5px 5px;
    margin: 0px;
}

.select2-container .select2-search--inline .select2-search__field {
    min-height: calc(42px - 18px);
    margin: 0px;
    font-family: inherit;
    color: inherit;
}

.select2-container--default .select2-selection--multiple .select2-selection__choice {
    margin: 0px;
}
