<ol class="breadcrumb float-sm-end">
    <li class="breadcrumb-item">
        <a href="{% block ecom_statics_home_url %}{% url 'home' %}{% endblock %}">Inicio</a>
    </li>
    
    {% for breadcrumb in breadcrumbs %}
        <li class="breadcrumb-item">
            {% if breadcrumb.url %}
                <a href="{{ breadcrumb.url }}">{{ breadcrumb.name }}</a>
            {% else %}
                {{ breadcrumb.name }}
            {% endif %}
        </li>
    {% endfor %}
</ol>
